@@ -1,6 +1,6 @@
 package Reddit::Client;
 
-our $VERSION = '1.085'; 
+our $VERSION = '1.086'; 
 $VERSION = eval $VERSION;
 
 use strict;
@@ -658,6 +658,7 @@ sub submit_link {
     my $title     = $param{title}     || croak 'Expected "title"';
     my $url       = $param{url}       || croak 'Expected "url"';
     my $replies = exists $param{inbox_replies} ? ($param{inbox_replies} ? "true" : "false") : "true";
+    my $repost = exists $param{repost} ? ($param{repost} ? "true" : "false") : "false";
 
     DEBUG('Submit link to %s: %s', $subreddit, $title, $url);
 
@@ -669,6 +670,7 @@ sub submit_link {
         sr       => $subreddit,
         kind     => SUBMIT_LINK,
 	sendreplies=>$replies,
+	resubmit => $repost,
     });
 
     return $result->{data}{name};
